@@ -53,14 +53,12 @@ class TutorCli(click.MultiCommand):
         """
         We enable plugins as soon as possible to have access to commands.
         """
-        if not isinstance(ctx, click.Context):
-            # When generating docs, this function is incorrectly called with a
-            # multicommand object instead of a Context. That's ok, we just
-            # ignore it.
-            # https://github.com/click-contrib/sphinx-click/issues/70
+        if not "root" in ctx.params:
+            # When generating docs, this function is called with empty args.
+            # That's ok, we just ignore it.
             return
         if not cls.IS_ROOT_READY:
-            hooks.Actions.PROJECT_ROOT_READY.do(root=ctx.params["root"])
+            hooks.Actions.PROJECT_ROOT_READY.do(ctx.params["root"])
             cls.IS_ROOT_READY = True
 
     def list_commands(self, ctx: click.Context) -> t.List[str]:
@@ -127,17 +125,8 @@ def help_command(context: click.Context) -> None:
     context.invoke(cli, show_help=True)
 
 
-hooks.filters.add_items(
-    "cli:commands",
-    [
-        images_command,
-        config_command,
-        local,
-        dev,
-        k8s,
-        help_command,
-        plugins_command,
-    ],
+hooks.Filters.CLI_COMMANDS.add_items(
+    [images_command, config_command, local, dev, k8s, help_command, plugins_command]
 )
 
 
